@@ -11,9 +11,8 @@ from collections import OrderedDict
 import logging
 from .invoice_template import InvoiceTemplate
 import codecs
-import chardet
 
-logging.getLogger("chardet").setLevel(logging.WARNING)
+logger = logging.getLogger(__name__)
 
 
 # borrowed from http://stackoverflow.com/a/21912744
@@ -84,12 +83,14 @@ def read_templates(folder=None):
     for path, subdirs, files in os.walk(folder):
         for name in sorted(files):
             if name.endswith(".yml"):
-                with open(os.path.join(path, name), "rb") as f:
-                    encoding = chardet.detect(f.read())["encoding"]
                 with codecs.open(
-                    os.path.join(path, name), encoding=encoding
+                    os.path.join(path, name), encoding="utf-8"
                 ) as template_file:
-                    tpl = ordered_load(template_file.read())
+                    try:
+                        tpl = ordered_load(template_file.read())
+                    except yaml.parser.ParserError as error:
+                        logger.warning("Failed to load %s template:\n%s", name, error)
+                        continue
                 tpl["template_name"] = name
 
                 # Test if all required fields are in template:
@@ -107,4 +108,7 @@ def read_templates(folder=None):
                     tpl["exclude_keywords"] = [tpl["exclude_keywords"]]
 
                 output.append(InvoiceTemplate(tpl))
+
+    logger.info("Loaded %d templates from %s", len(output), folder)
+
     return output
